@@ -40,7 +40,7 @@ import os
 import sys
 import subprocess
 from loguru import logger as lgr
-from .private_constants import *
+from private_constants import *
 # from applogger import AppLogger, Log
 from usbhandler import USBHandler
 from settings import Settings
@@ -1128,8 +1128,7 @@ def check_requirements():
         return (False, missing)
     return (True, None)
 
-app = SingleInstanceApp([])
-window = None
+
 
 if __name__ == '__main__':
     with lgr.catch(message='Encountered exception from main.',
@@ -1143,7 +1142,7 @@ if __name__ == '__main__':
             sys.exit(1)
 
         # app = SingleInstanceApp([])
-
+        app = SingleInstanceApp([])
         if app.is_running:
             lgr.critical(
                 "Another instance of the application is already running.")
